Documentation
¶
Overview ¶
Package values is a generated GoMock package.
Index ¶
- type BoolValues
- type BoolValuesBuilder
- type BoolValuesMetadata
- type BytesValues
- type BytesValuesBuilder
- type BytesValuesMetadata
- type CloseableBoolValues
- type CloseableBytesValues
- type CloseableDoubleValues
- type CloseableIntValues
- type CloseableTimeValues
- type DoubleValues
- type DoubleValuesBuilder
- type DoubleValuesMetadata
- type IntValues
- type IntValuesBuilder
- type IntValuesMetadata
- type MetaUnion
- type MockBoolValues
- type MockBoolValuesMockRecorder
- type MockBytesValues
- func (m *MockBytesValues) EXPECT() *MockBytesValuesMockRecorder
- func (m *MockBytesValues) Filter(arg0 filter.Op, arg1 *field.ValueUnion) (iterator.PositionIterator, error)
- func (m *MockBytesValues) Iter() (iterator.ForwardBytesIterator, error)
- func (m *MockBytesValues) Metadata() BytesValuesMetadata
- type MockBytesValuesMockRecorder
- type MockDoubleValues
- func (m *MockDoubleValues) EXPECT() *MockDoubleValuesMockRecorder
- func (m *MockDoubleValues) Filter(arg0 filter.Op, arg1 *field.ValueUnion) (iterator.PositionIterator, error)
- func (m *MockDoubleValues) Iter() (iterator.ForwardDoubleIterator, error)
- func (m *MockDoubleValues) Metadata() DoubleValuesMetadata
- type MockDoubleValuesMockRecorder
- type MockIntValues
- type MockIntValuesMockRecorder
- type MockTimeValues
- type MockTimeValuesMockRecorder
- type TimeValues
- type TimeValuesBuilder
- type TimeValuesMetadata
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BoolValues ¶
type BoolValues interface {
// Metadata returns the collection metadata.
Metadata() BoolValuesMetadata
// Iter returns an iterator to provides iterative access to the underlying dataset
// when the iterator is created. After the iterator is returned, the iterator has
// no access to future values added to the underlying dataset. The iterator remains
// valid until the bool values collection is closed.
Iter() (iterator.ForwardBoolIterator, error)
// Filter applies the given filter against the values, returning an iterator
// identifying the positions of values matching the filter.
Filter(op filter.Op, filterValue *field.ValueUnion) (iterator.PositionIterator, error)
}
BoolValues is an immutable collection of bool values.
type BoolValuesBuilder ¶
type BoolValuesBuilder interface {
// Add adds a bool to the collection.
Add(v bool) error
// Snapshot takes a snapshot of the bool values collected so far.
Snapshot() CloseableBoolValues
// Seal seals and closes the mutable collection, and returns an
// immutable bool values collection. The resource ownership is
// transferred from the builder to the immutable collection as a result.
// Adding more data to the builder after the builder is sealed will result
// in an error.
Seal() CloseableBoolValues
// Close closes the builder. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
BoolValuesBuilder incrementally builds the bool value collection.
type BoolValuesMetadata ¶
BoolValuesMetadata contains the metadata for the bool values collection.
type BytesValues ¶
type BytesValues interface {
// Metadata returns the collection metadata.
Metadata() BytesValuesMetadata
// Iter returns an iterator to provides iterative access to the underlying dataset
// when the iterator is created. After the iterator is returned, the iterator has
// no access to future values added to the underlying dataset. The iterator remains
// valid until the bytes values collection is closed.
Iter() (iterator.ForwardBytesIterator, error)
// Filter applies the given filter against the values, returning an iterator
// identifying the positions of values matching the filter.
Filter(op filter.Op, filterValue *field.ValueUnion) (iterator.PositionIterator, error)
}
BytesValues is an immutable collection of bytes values.
type BytesValuesBuilder ¶
type BytesValuesBuilder interface {
// Add adds a bytes to the collection.
Add(v []byte) error
// Snapshot takes a snapshot of the bytes values collected so far.
Snapshot() CloseableBytesValues
// Seal seals and closes the mutable collection, and returns an
// immutable bytes values collection. The resource ownership is
// transferred from the builder to the immutable collection as a result.
// Adding more data to the builder after the builder is sealed will result
// in an error.
Seal() CloseableBytesValues
// Close closes the builder. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
BytesValuesBuilder incrementally builds the bytes value collection.
type BytesValuesMetadata ¶
BytesValuesMetadata contains the metadata for the bytes values collection.
type CloseableBoolValues ¶
type CloseableBoolValues interface {
BoolValues
// Close closes the value collection. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
CloseableBoolValues is a collection of bool values that can be closed.
type CloseableBytesValues ¶
type CloseableBytesValues interface {
BytesValues
// Close closes the value collection. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
CloseableBytesValues is a bytes values collection that can be closed.
type CloseableDoubleValues ¶
type CloseableDoubleValues interface {
DoubleValues
// Close closes the value collection. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
CloseableDoubleValues is a collection of double values that can be closed.
type CloseableIntValues ¶
type CloseableIntValues interface {
IntValues
// Close closes the value collection. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
CloseableIntValues is a collection of int values that can be closed.
type CloseableTimeValues ¶
type CloseableTimeValues interface {
TimeValues
// Close closes the value collection. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
CloseableTimeValues is a collection of time values that can be closed.
type DoubleValues ¶
type DoubleValues interface {
// Metadata returns the collection metadata.
Metadata() DoubleValuesMetadata
// Iter returns an iterator to provides iterative access to the underlying dataset
// when the iterator is created. After the iterator is returned, the iterator has
// no access to future values added to the underlying dataset. The iterator remains
// valid until the double values collection is closed.
Iter() (iterator.ForwardDoubleIterator, error)
// Filter applies the given filter against the values, returning an iterator
// identifying the positions of values matching the filter.
Filter(op filter.Op, filterValue *field.ValueUnion) (iterator.PositionIterator, error)
}
DoubleValues is an immutable collection of double values.
type DoubleValuesBuilder ¶
type DoubleValuesBuilder interface {
// Add adds a double to the collection.
Add(v float64) error
// Snapshot takes a snapshot of the double values collected so far.
Snapshot() CloseableDoubleValues
// Seal seals and closes the mutable collection, and returns an
// immutable double values collection. The resource ownership is
// transferred from the builder to the immutable collection as a result.
// Adding more data to the builder after the builder is sealed will result
// in an error.
Seal() CloseableDoubleValues
// Close closes the builder. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
DoubleValuesBuilder incrementally builds the double value collection.
type DoubleValuesMetadata ¶
DoubleValuesMetadata contains the metadata for the double values collection.
type IntValues ¶
type IntValues interface {
// Metadata returns the collection metadata.
Metadata() IntValuesMetadata
// Iter returns an iterator to provides iterative access to the underlying dataset
// when the iterator is created. After the iterator is returned, the iterator has
// no access to future values added to the underlying dataset. The iterator remains
// valid until the int values collection is closed.
Iter() (iterator.ForwardIntIterator, error)
// Filter applies the given filter against the values, returning an iterator
// identifying the positions of values matching the filter.
Filter(op filter.Op, filterValue *field.ValueUnion) (iterator.PositionIterator, error)
}
IntValues is an immutable collection of int values.
type IntValuesBuilder ¶
type IntValuesBuilder interface {
// Add adds a int to the collection.
Add(v int) error
// Snapshot takes a snapshot of the int values collected so far.
Snapshot() CloseableIntValues
// Seal seals and closes the mutable collection, and returns an
// immutable int values collection. The resource ownership is
// transferred from the builder to the immutable collection as a result.
// Adding more data to the builder after the builder is sealed will result
// in an error.
Seal() CloseableIntValues
// Close closes the builder. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
IntValuesBuilder incrementally builds the int value collection.
type IntValuesMetadata ¶
IntValuesMetadata contains the metadata for the int values collection.
type MetaUnion ¶
type MetaUnion struct {
Type field.ValueType
BoolMeta BoolValuesMetadata
IntMeta IntValuesMetadata
DoubleMeta DoubleValuesMetadata
BytesMeta BytesValuesMetadata
TimeMeta TimeValuesMetadata
}
MetaUnion is a union of values meta.
func (*MetaUnion) MustToMinMaxValueUnion ¶
func (u *MetaUnion) MustToMinMaxValueUnion() (minUnion, maxUnion field.ValueUnion)
MustToMinMaxValueUnion extracts the min value union and max value union from the meta union, and panics if an error is encountered.
func (*MetaUnion) ToMinMaxValueUnion ¶
func (u *MetaUnion) ToMinMaxValueUnion() (minUnion, maxUnion field.ValueUnion, err error)
ToMinMaxValueUnion extracts the min value union and max value union from the meta union.
type MockBoolValues ¶
type MockBoolValues struct {
// contains filtered or unexported fields
}
MockBoolValues is a mock of BoolValues interface
func NewMockBoolValues ¶
func NewMockBoolValues(ctrl *gomock.Controller) *MockBoolValues
NewMockBoolValues creates a new mock instance
func (*MockBoolValues) EXPECT ¶
func (m *MockBoolValues) EXPECT() *MockBoolValuesMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBoolValues) Filter ¶
func (m *MockBoolValues) Filter(arg0 filter.Op, arg1 *field.ValueUnion) (iterator.PositionIterator, error)
Filter mocks base method
func (*MockBoolValues) Iter ¶
func (m *MockBoolValues) Iter() (iterator.ForwardBoolIterator, error)
Iter mocks base method
func (*MockBoolValues) Metadata ¶
func (m *MockBoolValues) Metadata() BoolValuesMetadata
Metadata mocks base method
type MockBoolValuesMockRecorder ¶
type MockBoolValuesMockRecorder struct {
// contains filtered or unexported fields
}
MockBoolValuesMockRecorder is the mock recorder for MockBoolValues
func (*MockBoolValuesMockRecorder) Filter ¶
func (mr *MockBoolValuesMockRecorder) Filter(arg0, arg1 interface{}) *gomock.Call
Filter indicates an expected call of Filter
func (*MockBoolValuesMockRecorder) Iter ¶
func (mr *MockBoolValuesMockRecorder) Iter() *gomock.Call
Iter indicates an expected call of Iter
func (*MockBoolValuesMockRecorder) Metadata ¶
func (mr *MockBoolValuesMockRecorder) Metadata() *gomock.Call
Metadata indicates an expected call of Metadata
type MockBytesValues ¶
type MockBytesValues struct {
// contains filtered or unexported fields
}
MockBytesValues is a mock of BytesValues interface
func NewMockBytesValues ¶
func NewMockBytesValues(ctrl *gomock.Controller) *MockBytesValues
NewMockBytesValues creates a new mock instance
func (*MockBytesValues) EXPECT ¶
func (m *MockBytesValues) EXPECT() *MockBytesValuesMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBytesValues) Filter ¶
func (m *MockBytesValues) Filter(arg0 filter.Op, arg1 *field.ValueUnion) (iterator.PositionIterator, error)
Filter mocks base method
func (*MockBytesValues) Iter ¶
func (m *MockBytesValues) Iter() (iterator.ForwardBytesIterator, error)
Iter mocks base method
func (*MockBytesValues) Metadata ¶
func (m *MockBytesValues) Metadata() BytesValuesMetadata
Metadata mocks base method
type MockBytesValuesMockRecorder ¶
type MockBytesValuesMockRecorder struct {
// contains filtered or unexported fields
}
MockBytesValuesMockRecorder is the mock recorder for MockBytesValues
func (*MockBytesValuesMockRecorder) Filter ¶
func (mr *MockBytesValuesMockRecorder) Filter(arg0, arg1 interface{}) *gomock.Call
Filter indicates an expected call of Filter
func (*MockBytesValuesMockRecorder) Iter ¶
func (mr *MockBytesValuesMockRecorder) Iter() *gomock.Call
Iter indicates an expected call of Iter
func (*MockBytesValuesMockRecorder) Metadata ¶
func (mr *MockBytesValuesMockRecorder) Metadata() *gomock.Call
Metadata indicates an expected call of Metadata
type MockDoubleValues ¶
type MockDoubleValues struct {
// contains filtered or unexported fields
}
MockDoubleValues is a mock of DoubleValues interface
func NewMockDoubleValues ¶
func NewMockDoubleValues(ctrl *gomock.Controller) *MockDoubleValues
NewMockDoubleValues creates a new mock instance
func (*MockDoubleValues) EXPECT ¶
func (m *MockDoubleValues) EXPECT() *MockDoubleValuesMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockDoubleValues) Filter ¶
func (m *MockDoubleValues) Filter(arg0 filter.Op, arg1 *field.ValueUnion) (iterator.PositionIterator, error)
Filter mocks base method
func (*MockDoubleValues) Iter ¶
func (m *MockDoubleValues) Iter() (iterator.ForwardDoubleIterator, error)
Iter mocks base method
func (*MockDoubleValues) Metadata ¶
func (m *MockDoubleValues) Metadata() DoubleValuesMetadata
Metadata mocks base method
type MockDoubleValuesMockRecorder ¶
type MockDoubleValuesMockRecorder struct {
// contains filtered or unexported fields
}
MockDoubleValuesMockRecorder is the mock recorder for MockDoubleValues
func (*MockDoubleValuesMockRecorder) Filter ¶
func (mr *MockDoubleValuesMockRecorder) Filter(arg0, arg1 interface{}) *gomock.Call
Filter indicates an expected call of Filter
func (*MockDoubleValuesMockRecorder) Iter ¶
func (mr *MockDoubleValuesMockRecorder) Iter() *gomock.Call
Iter indicates an expected call of Iter
func (*MockDoubleValuesMockRecorder) Metadata ¶
func (mr *MockDoubleValuesMockRecorder) Metadata() *gomock.Call
Metadata indicates an expected call of Metadata
type MockIntValues ¶
type MockIntValues struct {
// contains filtered or unexported fields
}
MockIntValues is a mock of IntValues interface
func NewMockIntValues ¶
func NewMockIntValues(ctrl *gomock.Controller) *MockIntValues
NewMockIntValues creates a new mock instance
func (*MockIntValues) EXPECT ¶
func (m *MockIntValues) EXPECT() *MockIntValuesMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockIntValues) Filter ¶
func (m *MockIntValues) Filter(arg0 filter.Op, arg1 *field.ValueUnion) (iterator.PositionIterator, error)
Filter mocks base method
func (*MockIntValues) Iter ¶
func (m *MockIntValues) Iter() (iterator.ForwardIntIterator, error)
Iter mocks base method
func (*MockIntValues) Metadata ¶
func (m *MockIntValues) Metadata() IntValuesMetadata
Metadata mocks base method
type MockIntValuesMockRecorder ¶
type MockIntValuesMockRecorder struct {
// contains filtered or unexported fields
}
MockIntValuesMockRecorder is the mock recorder for MockIntValues
func (*MockIntValuesMockRecorder) Filter ¶
func (mr *MockIntValuesMockRecorder) Filter(arg0, arg1 interface{}) *gomock.Call
Filter indicates an expected call of Filter
func (*MockIntValuesMockRecorder) Iter ¶
func (mr *MockIntValuesMockRecorder) Iter() *gomock.Call
Iter indicates an expected call of Iter
func (*MockIntValuesMockRecorder) Metadata ¶
func (mr *MockIntValuesMockRecorder) Metadata() *gomock.Call
Metadata indicates an expected call of Metadata
type MockTimeValues ¶
type MockTimeValues struct {
// contains filtered or unexported fields
}
MockTimeValues is a mock of TimeValues interface
func NewMockTimeValues ¶
func NewMockTimeValues(ctrl *gomock.Controller) *MockTimeValues
NewMockTimeValues creates a new mock instance
func (*MockTimeValues) EXPECT ¶
func (m *MockTimeValues) EXPECT() *MockTimeValuesMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockTimeValues) Filter ¶
func (m *MockTimeValues) Filter(arg0 filter.Op, arg1 *field.ValueUnion) (iterator.PositionIterator, error)
Filter mocks base method
func (*MockTimeValues) Iter ¶
func (m *MockTimeValues) Iter() (iterator.ForwardTimeIterator, error)
Iter mocks base method
func (*MockTimeValues) Metadata ¶
func (m *MockTimeValues) Metadata() TimeValuesMetadata
Metadata mocks base method
type MockTimeValuesMockRecorder ¶
type MockTimeValuesMockRecorder struct {
// contains filtered or unexported fields
}
MockTimeValuesMockRecorder is the mock recorder for MockTimeValues
func (*MockTimeValuesMockRecorder) Filter ¶
func (mr *MockTimeValuesMockRecorder) Filter(arg0, arg1 interface{}) *gomock.Call
Filter indicates an expected call of Filter
func (*MockTimeValuesMockRecorder) Iter ¶
func (mr *MockTimeValuesMockRecorder) Iter() *gomock.Call
Iter indicates an expected call of Iter
func (*MockTimeValuesMockRecorder) Metadata ¶
func (mr *MockTimeValuesMockRecorder) Metadata() *gomock.Call
Metadata indicates an expected call of Metadata
type TimeValues ¶
type TimeValues interface {
// Metadata returns the collection metadata.
Metadata() TimeValuesMetadata
// Iter returns an iterator to provides iterative access to the underlying dataset
// when the iterator is created. After the iterator is returned, the iterator has
// no access to future values added to the underlying dataset. The iterator remains
// valid until the time values collection is closed.
Iter() (iterator.ForwardTimeIterator, error)
// Filter applies the given filter against the values, returning an iterator
// identifying the positions of values matching the filter.
Filter(op filter.Op, filterValue *field.ValueUnion) (iterator.PositionIterator, error)
}
TimeValues is an immutable collection of time values.
type TimeValuesBuilder ¶
type TimeValuesBuilder interface {
// Add adds a time to the collection.
Add(v int64) error
// Snapshot takes a snapshot of the time values collected so far.
Snapshot() CloseableTimeValues
// Seal seals and closes the mutable collection, and returns an
// immutable time values collection. The resource ownership is
// transferred from the builder to the immutable collection as a result.
// Adding more data to the builder after the builder is sealed will result
// in an error.
Seal() CloseableTimeValues
// Close closes the builder. It will also release the resources held for
// the collection iff there is no one holding references to the collection.
Close()
}
TimeValuesBuilder incrementally builds the time value collection.
type TimeValuesMetadata ¶
TimeValuesMetadata contains the metadata for the time values collection.