decoding

package
v0.0.0-...-ad801e6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2019 License: Apache-2.0 Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BoolDec

type BoolDec struct{}

BoolDec is a bool decoder.

func NewBoolDecoder

func NewBoolDecoder() *BoolDec

NewBoolDecoder creates a new bool decoder.

func (*BoolDec) DecodeRaw

func (dec *BoolDec) DecodeRaw(data []byte) (values.CloseableBoolValues, error)

DecodeRaw decodes raw encoded bytes into a closeable bool values.

type BoolDecoder

type BoolDecoder interface {
	// DecodeRaw decodes raw encoded bytes into a closeable bool values.
	DecodeRaw(data []byte) (values.CloseableBoolValues, error)
}

BoolDecoder decodes bool values.

type BytesDecoder

type BytesDecoder interface {
	// DecodeRaw decodes raw encoded bytes into a closeable bytes values.
	DecodeRaw(data []byte) (values.CloseableBytesValues, error)
}

BytesDecoder decodes bytes values.

func NewBytesDecoder

func NewBytesDecoder() BytesDecoder

NewBytesDecoder creates a new bytes decoder.

type DoubleDecoder

type DoubleDecoder interface {
	// DecodeRaw decodes raw encoded bytes into a closeable double values.
	DecodeRaw(data []byte) (values.CloseableDoubleValues, error)
}

DoubleDecoder decodes double values.

func NewDoubleDecoder

func NewDoubleDecoder() DoubleDecoder

NewDoubleDecoder creates a new double Decoder.

type IntDecoder

type IntDecoder interface {
	// DecodeRaw decodes raw encoded bytes into a closeable int values.
	DecodeRaw(data []byte) (values.CloseableIntValues, error)
}

IntDecoder decodes int values.

func NewIntDecoder

func NewIntDecoder() IntDecoder

NewIntDecoder creates a new int Decoder.

type TimeDecoder

type TimeDecoder interface {
	// DecodeRaw decodes raw encoded bytes into a closeable time values.
	DecodeRaw(data []byte) (values.CloseableTimeValues, error)
}

TimeDecoder decodes time values.

func NewTimeDecoder

func NewTimeDecoder() TimeDecoder

NewTimeDecoder creates a new time decoder.

Jump to